@@ -242,45 +242,46 @@ stopifnot(all(y - yhat == w3$y))
 plotmo(gbm.laplace, trace=-1, SHOWCALL=TRUE)
 par(old.par)
 
-cat("--- distribution=\"tdist\" ----------------------------------\n")
-
-set.seed(2016)
-ptit <- ptitanic[sample(1:nrow(ptitanic), size=70), ]
-ptit <- ptit[!is.na(ptit$age), ]
-ptit$survived <- ptit$parch <- ptit$sex <- NULL
-train.frac <- .8
-set.seed(2016)
-gbm.tdist <- gbm(age~., data=ptit, train.frac=train.frac,
-                   distribution="tdist",
-                   n.trees=100, shrinkage=.1)
-old.par <- par(no.readonly=TRUE)
-par(mfrow=c(2,2), mar=c(3,3,4,1))
-set.seed(2016)
-w1 <- plotres(gbm.tdist, which=1:2, do.par=FALSE,
-        w1.main="gbm.tdist")
-
-cat("w1 plot for gbm.tdist returned (w1.smooth=default):\n")
-print(w1)
-
-set.seed(2016)
-w3 <- plotres(gbm.tdist, which=3, do.par=FALSE, info=TRUE)
-
-# compare to manual residuals
-iused <- 1:(train.frac * nrow(ptit))
-y <- ptit$age[iused]
-n.trees <- plotmo:::gbm.n.trees(gbm.tdist)
-# TODO following fails in the new version of gbm (version 2.2) (you have to provide newdata)
-# yhat <- predict(gbm.tdist, type="response", n.trees=n.trees)
-yhat <- predict(gbm.tdist, newdata=ptit, type="response", n.trees=n.trees)
-yhat <- yhat[iused]
-plot(yhat, y - yhat,
-     main="manual tdist residuals",
-     pch=20, ylim=c(-40,40))
-abline(h=0, col="gray")
-stopifnot(all(yhat == w3$x))
-stopifnot(all(y - yhat == w3$y))
-plotmo(gbm.tdist, trace=-1, SHOWCALL=TRUE)
-par(old.par)
+# # TODO commented out because gives random slightly different results per invocation
+# cat("--- distribution=\"tdist\" ----------------------------------\n")
+#
+# set.seed(2016)
+# ptit <- ptitanic[sample(1:nrow(ptitanic), size=70), ]
+# ptit <- ptit[!is.na(ptit$age), ]
+# ptit$survived <- ptit$parch <- ptit$sex <- NULL
+# train.frac <- .8
+# set.seed(2016)
+# gbm.tdist <- gbm(age~., data=ptit, train.frac=train.frac,
+#                    distribution="tdist",
+#                    n.trees=100, shrinkage=.1)
+# old.par <- par(no.readonly=TRUE)
+# par(mfrow=c(2,2), mar=c(3,3,4,1))
+# set.seed(2016)
+# w1 <- plotres(gbm.tdist, which=1:2, do.par=FALSE,
+#         w1.main="gbm.tdist")
+#
+# cat("w1 plot for gbm.tdist returned (w1.smooth=default):\n")
+# print(w1)
+#
+# set.seed(2016)
+# w3 <- plotres(gbm.tdist, which=3, do.par=FALSE, info=TRUE)
+#
+# # compare to manual residuals
+# iused <- 1:(train.frac * nrow(ptit))
+# y <- ptit$age[iused]
+# n.trees <- plotmo:::gbm.n.trees(gbm.tdist)
+# # TODO following fails in the new version of gbm (version 2.2) (you have to provide newdata)
+# # yhat <- predict(gbm.tdist, type="response", n.trees=n.trees)
+# yhat <- predict(gbm.tdist, newdata=ptit, type="response", n.trees=n.trees)
+# yhat <- yhat[iused]
+# plot(yhat, y - yhat,
+#      main="manual tdist residuals",
+#      pch=20, ylim=c(-40,40))
+# abline(h=0, col="gray")
+# stopifnot(all(yhat == w3$x))
+# stopifnot(all(y - yhat == w3$y))
+# plotmo(gbm.tdist, trace=-1, SHOWCALL=TRUE)
+# par(old.par)
 
 cat("--- distribution=\"bernoulli\" ----------------------------------\n")
 
